MINOR: stream-int: replace SI_FL_WANT_PUT with !SI_FL_RX_WAIT_EP

The SI_FL_WANT_PUT flag is used in an awkward way, sometimes it's
set by the stream-interface to mean "I have something to deliver",
sometimes it's cleared by the channel to say "I don't want you to
send what you have", and it has to be set back once CF_DONT_READ
is cleared. This will have to be split between SI_FL_RX_WAIT_EP
and SI_FL_RXBLK_CHAN. This patch only replaces all uses of the
flag with its natural (but negated) replacement SI_FL_RX_WAIT_EP.
The code is expected to be strictly equivalent. The now unused flag
was completely removed.
diff --git a/include/proto/stream_interface.h b/include/proto/stream_interface.h
index 6d46381..9100778 100644
--- a/include/proto/stream_interface.h
+++ b/include/proto/stream_interface.h
@@ -262,25 +262,27 @@
 /* Report that a stream interface wants to put some data into the input buffer */
 static inline void si_want_put(struct stream_interface *si)
 {
-	si->flags |= SI_FL_WANT_PUT;
+	si->flags &= ~SI_FL_RX_WAIT_EP;
 }
 
 /* Report that a stream interface failed to put some data into the input buffer */
 static inline void si_cant_put(struct stream_interface *si)
 {
-	si->flags |= SI_FL_WANT_PUT | SI_FL_RXBLK_ROOM;
+	si->flags |=  SI_FL_RXBLK_ROOM;
+	si->flags &= ~SI_FL_RX_WAIT_EP;
 }
 
 /* Report that a stream interface doesn't want to put data into the input buffer */
 static inline void si_stop_put(struct stream_interface *si)
 {
-	si->flags &= ~SI_FL_WANT_PUT;
+	si->flags |=  SI_FL_RX_WAIT_EP;
 }
 
 /* Report that a stream interface won't put any more data into the input buffer */
 static inline void si_done_put(struct stream_interface *si)
 {
-	si->flags &= ~(SI_FL_WANT_PUT | SI_FL_RXBLK_ROOM);
+	si->flags &= ~SI_FL_RXBLK_ROOM;
+	si->flags |=  SI_FL_RX_WAIT_EP;
 }
 
 /* Returns non-zero if the stream interface's Rx path is blocked */
@@ -387,7 +389,7 @@
 }
 
 /* This is to be used after making some room available in a channel. It will
  * return without doing anything if {SI_FL_WANT_PUT,SI_FL_RXBLK_ROOM} != {1,0}.
  * It will then call ->chk_rcv() to enable receipt of new data.
  */
 static inline void si_chk_rcv(struct stream_interface *si)
@@ -395,13 +397,13 @@
 	if (si->flags & SI_FL_RXBLK_ROOM)
 		return;
 
-	if (!(si->flags & SI_FL_WANT_PUT))
+	if (si->flags & SI_FL_RX_WAIT_EP)
 		return;
 
 	if (si->state > SI_ST_EST)
 		return;
 
-	si->flags &= ~SI_FL_WANT_PUT;
+	si->flags |= SI_FL_RX_WAIT_EP;
 	si->ops->chk_rcv(si);
 }
@@ -387,7 +389,7 @@
 
 /* This is to be used after making some room available in a channel. It will
- * return without doing anything if {SI_FL_WANT_PUT,SI_FL_RXBLK_ROOM} != {1,0}.
+ * return without doing anything if {SI_FL_RX_WAIT_EP,SI_FL_RXBLK_ROOM} != {0,0}.
  * It will then call ->chk_rcv() to enable receipt of new data.
  */